==> extdirectspring-1.0.8-sources.jar: ch/ralscha/extdirectspring/bean/SortInfo.java <==
/**
 * Copyright 2010-2011 Ralph Schaer <ralphschaer@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ch.ralscha.extdirectspring.bean;

import java.util.Map;

public class SortInfo {
	private String property;
	private SortDirection direction;

	public SortInfo(String property, SortDirection direction) {
		this.property = property;
		this.direction = direction;
	}
	
	public String getProperty() {
		return property;
	}

	public void setProperty(String property) {
		this.property = property;
	}

	public SortDirection getDirection() {
		return direction;
	}

	public void setDirection(SortDirection direction) {
		this.direction = direction;
	}

	public static SortInfo createSortInfo(final Map<String, Object> jsonData) {
		String property = (String) jsonData.get("property");
		String direction = (String) jsonData.get("direction");

		SortInfo sortInfo = new SortInfo(property, SortDirection.fromString(direction));
		
		return sortInfo;
	}

	@Override
	public String toString() {
		return "SortInfo [property=" + property + ", direction=" + direction + "]";
	}
	
}

==> extdirectspring-1.1.0-sources.jar: ch/ralscha/extdirectspring/bean/SortInfo.java <==
/**
 * Copyright 2010-2012 Ralph Schaer <ralphschaer@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ch.ralscha.extdirectspring.bean;

import java.util.Map;

/**
 * Class contains information about the property/field on which to sort and if sort
 * is ascending or descending. ExtJs can send more than one sort info in one
 * request.
 * 
 * @author Ralph Schaer
 */
public class SortInfo {
	private String property;

	private SortDirection direction;

	public SortInfo(final String property, final SortDirection direction) {
		this.property = property;
		this.direction = direction;
	}

	public String getProperty() {
		return property;
	}

	public SortDirection getDirection() {
		return direction;
	}

	public static SortInfo create(final Map<String, Object> jsonData) {
		String property = (String) jsonData.get("property");
		String direction = (String) jsonData.get("direction");

		SortInfo sortInfo = new SortInfo(property, SortDirection.fromString(direction));

		return sortInfo;
	}

	@Override
	public String toString() {
		return "SortInfo [property=" + property + ", direction=" + direction + "]";
	}

}
